Class: DSP::BreakpointEvent

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface BreakpointEvent extends Event { body: { /** The reason for the event. Values: 'changed', 'new', 'removed', etc. / reason: string; /* The 'id' attribute is used to find the target breakpoint and the other attributes are used as the new values. */ breakpoint: Breakpoint; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#initialize, #to_h, #to_json

Constructor Details

This class inherits a constructor from DSP::DSPBase

Instance Attribute Details

#bodyObject

type: {



490
491
492
# File 'lib/dsp/dsp_protocol.rb', line 490

def body
  @body
end

#eventObject

/** The reason for the event. Values: 'changed', 'new', 'removed', etc. / reason: string; /* The 'id' attribute is used to find the target breakpoint and the other attributes are used as the new values. */ breakpoint: Breakpoint; }



498
499
500
# File 'lib/dsp/dsp_protocol.rb', line 498

def event
  @event
end

#seqObject

type: {



490
491
492
# File 'lib/dsp/dsp_protocol.rb', line 490

def seq
  @seq
end

#typeObject

type: {



490
491
492
# File 'lib/dsp/dsp_protocol.rb', line 490

def type
  @type
end

Instance Method Details

#from_h!(value) ⇒ Object



500
501
502
503
504
505
506
507
# File 'lib/dsp/dsp_protocol.rb', line 500

def from_h!(value)
  value = {} if value.nil?
  self.body = value['body'] # Unknown type
  self.event = value['event']
  self.seq = value['seq']
  self.type = value['type']
  self
end