Class: DSP::EvaluateResponse

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface EvaluateResponse extends Response { body: { /** The result of the evaluate request. / result: string; /* The optional type of the evaluate result. This attribute should only be returned by a debug adapter if the client has passed the value true for the 'supportsVariableType' capability of the 'initialize' request. / type?: string; /* Properties of a evaluate result that can be used to determine how to render the result in the UI. / presentationHint?: VariablePresentationHint; /* If variablesReference is > 0, the evaluate result is structured and its children can be retrieved by passing variablesReference to the VariablesRequest. The value should be less than or equal to 2147483647 (2^31 - 1). / variablesReference: number; /* The number of named child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / namedVariables?: number; /* The number of indexed child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / indexedVariables?: number; /* Optional memory reference to a location appropriate for this result. For pointer type eval results, this is generally a reference to the memory address contained in the pointer. This attribute should be returned by a debug adapter if the client has passed the value true for the 'supportsMemoryReferences' capability of the 'initialize' request. */ memoryReference?: string; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ EvaluateResponse

Returns a new instance of EvaluateResponse.



2999
3000
3001
3002
# File 'lib/dsp/dsp_protocol.rb', line 2999

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[message]
end

Instance Attribute Details

#bodyObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def body
  @body
end

#commandObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def command
  @command
end

#messageObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def message
  @message
end

#request_seqObject

/** The result of the evaluate request. / result: string; /* The optional type of the evaluate result. This attribute should only be returned by a debug adapter if the client has passed the value true for the 'supportsVariableType' capability of the 'initialize' request. / type?: string; /* Properties of a evaluate result that can be used to determine how to render the result in the UI. / presentationHint?: VariablePresentationHint; /* If variablesReference is > 0, the evaluate result is structured and its children can be retrieved by passing variablesReference to the VariablesRequest. The value should be less than or equal to 2147483647 (2^31 - 1). / variablesReference: number; /* The number of named child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / namedVariables?: number; /* The number of indexed child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / indexedVariables?: number; /* Optional memory reference to a location appropriate for this result. For pointer type eval results, this is generally a reference to the memory address contained in the pointer. This attribute should be returned by a debug adapter if the client has passed the value true for the 'supportsMemoryReferences' capability of the 'initialize' request. */ memoryReference?: string; }



2997
2998
2999
# File 'lib/dsp/dsp_protocol.rb', line 2997

def request_seq
  @request_seq
end

#seqObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def seq
  @seq
end

#successObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def success
  @success
end

#typeObject

type: {



2968
2969
2970
# File 'lib/dsp/dsp_protocol.rb', line 2968

def type
  @type
end

Instance Method Details

#from_h!(value) ⇒ Object



3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
# File 'lib/dsp/dsp_protocol.rb', line 3004

def from_h!(value)
  value = {} if value.nil?
  self.body = value['body'] # Unknown type
  self.request_seq = value['request_seq']
  self.success = value['success'] # Unknown type
  self.command = value['command']
  self.message = value['message']
  self.seq = value['seq']
  self.type = value['type']
  self
end