Class: DSP::ExceptionInfoResponse

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface ExceptionInfoResponse extends Response { body: { /** ID of the exception that was thrown. / exceptionId: string; /* Descriptive text for the exception provided by the debug adapter. / description?: string; /* Mode that caused the exception notification to be raised. / breakMode: ExceptionBreakMode; /* Detailed information about the exception. */ details?: ExceptionDetails; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ ExceptionInfoResponse

Returns a new instance of ExceptionInfoResponse.



3395
3396
3397
3398
# File 'lib/dsp/dsp_protocol.rb', line 3395

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[message]
end

Instance Attribute Details

#bodyObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def body
  @body
end

#commandObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def command
  @command
end

#messageObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def message
  @message
end

#request_seqObject

/** ID of the exception that was thrown. / exceptionId: string; /* Descriptive text for the exception provided by the debug adapter. / description?: string; /* Mode that caused the exception notification to be raised. / breakMode: ExceptionBreakMode; /* Detailed information about the exception. */ details?: ExceptionDetails; }



3393
3394
3395
# File 'lib/dsp/dsp_protocol.rb', line 3393

def request_seq
  @request_seq
end

#seqObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def seq
  @seq
end

#successObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def success
  @success
end

#typeObject

type: {



3383
3384
3385
# File 'lib/dsp/dsp_protocol.rb', line 3383

def type
  @type
end

Instance Method Details

#from_h!(value) ⇒ Object



3400
3401
3402
3403
3404
3405
3406
3407
3408
3409
3410
# File 'lib/dsp/dsp_protocol.rb', line 3400

def from_h!(value)
  value = {} if value.nil?
  self.body = value['body'] # Unknown type
  self.request_seq = value['request_seq']
  self.success = value['success'] # Unknown type
  self.command = value['command']
  self.message = value['message']
  self.seq = value['seq']
  self.type = value['type']
  self
end