Class: DSP::ExceptionOptions
Overview
interface ExceptionOptions { /** A path that selects a single or multiple exceptions in a tree. If 'path' is missing, the whole tree is selected. By convention the first segment of the path is a category that is used to group exceptions in the UI. / path?: ExceptionPathSegment; /* Condition when a thrown exception should result in a break. */ breakMode: ExceptionBreakMode; }
Instance Attribute Summary collapse
-
#breakMode ⇒ Object
type: ExceptionPathSegment # type: ExceptionBreakMode.
-
#path ⇒ Object
type: ExceptionPathSegment # type: ExceptionBreakMode.
Instance Method Summary collapse
- #from_h!(value) ⇒ Object
-
#initialize(initial_hash = nil) ⇒ ExceptionOptions
constructor
A new instance of ExceptionOptions.
Methods inherited from DSPBase
Constructor Details
#initialize(initial_hash = nil) ⇒ ExceptionOptions
Returns a new instance of ExceptionOptions.
4499 4500 4501 4502 |
# File 'lib/dsp/dsp_protocol.rb', line 4499 def initialize(initial_hash = nil) super @optional_method_names = %i[path] end |
Instance Attribute Details
#breakMode ⇒ Object
type: ExceptionPathSegment # type: ExceptionBreakMode
4497 4498 4499 |
# File 'lib/dsp/dsp_protocol.rb', line 4497 def breakMode @breakMode end |
#path ⇒ Object
type: ExceptionPathSegment # type: ExceptionBreakMode
4497 4498 4499 |
# File 'lib/dsp/dsp_protocol.rb', line 4497 def path @path end |
Instance Method Details
#from_h!(value) ⇒ Object
4504 4505 4506 4507 4508 4509 |
# File 'lib/dsp/dsp_protocol.rb', line 4504 def from_h!(value) value = {} if value.nil? self.path = to_typed_aray(value['path'], ExceptionPathSegment) self.breakMode = value['breakMode'] # Unknown type self end |