Class: DSP::FunctionBreakpoint

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface FunctionBreakpoint { /** The name of the function. / name: string; /* An optional expression for conditional breakpoints. It is only honored by a debug adapter if the capability 'supportsConditionalBreakpoints' is true. / condition?: string; /* An optional expression that controls how many hits of the breakpoint are ignored. The backend is expected to interpret the expression as needed. The attribute is only honored by a debug adapter if the capability 'supportsHitConditionalBreakpoints' is true. */ hitCondition?: string; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ FunctionBreakpoint

Returns a new instance of FunctionBreakpoint.



4222
4223
4224
4225
# File 'lib/dsp/dsp_protocol.rb', line 4222

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[condition hitCondition]
end

Instance Attribute Details

#conditionObject

type: string # type: string # type: string



4220
4221
4222
# File 'lib/dsp/dsp_protocol.rb', line 4220

def condition
  @condition
end

#hitConditionObject

type: string # type: string # type: string



4220
4221
4222
# File 'lib/dsp/dsp_protocol.rb', line 4220

def hitCondition
  @hitCondition
end

#nameObject

type: string # type: string # type: string



4220
4221
4222
# File 'lib/dsp/dsp_protocol.rb', line 4220

def name
  @name
end

Instance Method Details

#from_h!(value) ⇒ Object



4227
4228
4229
4230
4231
4232
4233
# File 'lib/dsp/dsp_protocol.rb', line 4227

def from_h!(value)
  value = {} if value.nil?
  self.name = value['name']
  self.condition = value['condition']
  self.hitCondition = value['hitCondition']
  self
end