Class: DSP::SetExpressionResponse

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface SetExpressionResponse extends Response { body: { /** The new value of the expression. / value: string; /* The optional type of the value. This attribute should only be returned by a debug adapter if the client has passed the value true for the 'supportsVariableType' capability of the 'initialize' request. / type?: string; /* Properties of a value that can be used to determine how to render the result in the UI. / presentationHint?: VariablePresentationHint; /* If variablesReference is > 0, the value is structured and its children can be retrieved by passing variablesReference to the VariablesRequest. The value should be less than or equal to 2147483647 (2^31 - 1). / variablesReference?: number; /* The number of named child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / namedVariables?: number; /* The number of indexed child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). */ indexedVariables?: number; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ SetExpressionResponse

Returns a new instance of SetExpressionResponse.



3114
3115
3116
3117
# File 'lib/dsp/dsp_protocol.rb', line 3114

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[message]
end

Instance Attribute Details

#bodyObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def body
  @body
end

#commandObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def command
  @command
end

#messageObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def message
  @message
end

#request_seqObject

/** The new value of the expression. / value: string; /* The optional type of the value. This attribute should only be returned by a debug adapter if the client has passed the value true for the 'supportsVariableType' capability of the 'initialize' request. / type?: string; /* Properties of a value that can be used to determine how to render the result in the UI. / presentationHint?: VariablePresentationHint; /* If variablesReference is > 0, the value is structured and its children can be retrieved by passing variablesReference to the VariablesRequest. The value should be less than or equal to 2147483647 (2^31 - 1). / variablesReference?: number; /* The number of named child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). / namedVariables?: number; /* The number of indexed child variables. The client can use this optional information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31 - 1). */ indexedVariables?: number; }



3112
3113
3114
# File 'lib/dsp/dsp_protocol.rb', line 3112

def request_seq
  @request_seq
end

#seqObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def seq
  @seq
end

#successObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def success
  @success
end

#typeObject

type: {



3088
3089
3090
# File 'lib/dsp/dsp_protocol.rb', line 3088

def type
  @type
end

Instance Method Details

#from_h!(value) ⇒ Object



3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
# File 'lib/dsp/dsp_protocol.rb', line 3119

def from_h!(value)
  value = {} if value.nil?
  self.body = value['body'] # Unknown type
  self.request_seq = value['request_seq']
  self.success = value['success'] # Unknown type
  self.command = value['command']
  self.message = value['message']
  self.seq = value['seq']
  self.type = value['type']
  self
end