Class: DSP::StoppedEvent

Inherits:
DSPBase show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface StoppedEvent extends Event { body: { /** The reason for the event. For backward compatibility this string is shown in the UI if the 'description' attribute is missing (but it must not be translated). Values: 'step', 'breakpoint', 'exception', 'pause', 'entry', 'goto', 'function breakpoint', 'data breakpoint', etc. / reason: string; /* The full reason for the event, e.g. 'Paused on exception'. This string is shown in the UI as is and must be translated. / description?: string; /* The thread which was stopped. / threadId?: number; /* A value of true hints to the frontend that this event should not change the focus. / preserveFocusHint?: boolean; /* Additional information. E.g. if reason is 'exception', text contains the exception name. This string is shown in the UI. / text?: string; /* If 'allThreadsStopped' is true, a debug adapter can announce that all threads have stopped. - The client should use this information to enable that all threads can be expanded to access their stacktraces. - If the attribute is missing or false, only the thread with the given threadId can be expanded. */ allThreadsStopped?: boolean; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#initialize, #to_h, #to_json

Constructor Details

This class inherits a constructor from DSP::DSPBase

Instance Attribute Details

#bodyObject

type: {



265
266
267
# File 'lib/dsp/dsp_protocol.rb', line 265

def body
  @body
end

#eventObject

/** The reason for the event. For backward compatibility this string is shown in the UI if the 'description' attribute is missing (but it must not be translated). Values: 'step', 'breakpoint', 'exception', 'pause', 'entry', 'goto', 'function breakpoint', 'data breakpoint', etc. / reason: string; /* The full reason for the event, e.g. 'Paused on exception'. This string is shown in the UI as is and must be translated. / description?: string; /* The thread which was stopped. / threadId?: number; /* A value of true hints to the frontend that this event should not change the focus. / preserveFocusHint?: boolean; /* Additional information. E.g. if reason is 'exception', text contains the exception name. This string is shown in the UI. / text?: string; /* If 'allThreadsStopped' is true, a debug adapter can announce that all threads have stopped. - The client should use this information to enable that all threads can be expanded to access their stacktraces. - If the attribute is missing or false, only the thread with the given threadId can be expanded. */ allThreadsStopped?: boolean; }



285
286
287
# File 'lib/dsp/dsp_protocol.rb', line 285

def event
  @event
end

#seqObject

type: {



265
266
267
# File 'lib/dsp/dsp_protocol.rb', line 265

def seq
  @seq
end

#typeObject

type: {



265
266
267
# File 'lib/dsp/dsp_protocol.rb', line 265

def type
  @type
end

Instance Method Details

#from_h!(value) ⇒ Object



287
288
289
290
291
292
293
294
# File 'lib/dsp/dsp_protocol.rb', line 287

def from_h!(value)
  value = {} if value.nil?
  self.body = value['body'] # Unknown type
  self.event = value['event']
  self.seq = value['seq']
  self.type = value['type']
  self
end