Class: DSP::VariablePresentationHint

Inherits:
DSPBase
  • Object
show all
Defined in:
lib/dsp/dsp_protocol.rb

Overview

interface VariablePresentationHint { /** The kind of variable. Before introducing additional values, try to use the listed values. Values: 'property': Indicates that the object is a property. 'method': Indicates that the object is a method. 'class': Indicates that the object is a class. 'data': Indicates that the object is data. 'event': Indicates that the object is an event. 'baseClass': Indicates that the object is a base class. 'innerClass': Indicates that the object is an inner class. 'interface': Indicates that the object is an interface. 'mostDerivedClass': Indicates that the object is the most derived class. 'virtual': Indicates that the object is virtual, that means it is a synthetic object introducedby the adapter for rendering purposes, e.g. an index range for large arrays. 'dataBreakpoint': Indicates that a data breakpoint is registered for the object. etc. / kind?: string; /* Set of attributes represented as an array of strings. Before introducing additional values, try to use the listed values. Values: 'static': Indicates that the object is static. 'constant': Indicates that the object is a constant. 'readOnly': Indicates that the object is read only. 'rawString': Indicates that the object is a raw string. 'hasObjectId': Indicates that the object can have an Object ID created for it. 'canHaveObjectId': Indicates that the object has an Object ID associated with it. 'hasSideEffects': Indicates that the evaluation had side effects. etc. / attributes?: string; /* Visibility of variable. Before introducing additional values, try to use the listed values. Values: 'public', 'private', 'protected', 'internal', 'final', etc. */ visibility?: string; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from DSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ VariablePresentationHint

Returns a new instance of VariablePresentationHint.



4125
4126
4127
4128
# File 'lib/dsp/dsp_protocol.rb', line 4125

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[kind attributes visibility]
end

Instance Attribute Details

#attributesObject

type: string # type: string # type: string



4123
4124
4125
# File 'lib/dsp/dsp_protocol.rb', line 4123

def attributes
  @attributes
end

#kindObject

type: string # type: string # type: string



4123
4124
4125
# File 'lib/dsp/dsp_protocol.rb', line 4123

def kind
  @kind
end

#visibilityObject

type: string # type: string # type: string



4123
4124
4125
# File 'lib/dsp/dsp_protocol.rb', line 4123

def visibility
  @visibility
end

Instance Method Details

#from_h!(value) ⇒ Object



4130
4131
4132
4133
4134
4135
4136
# File 'lib/dsp/dsp_protocol.rb', line 4130

def from_h!(value)
  value = {} if value.nil?
  self.kind = value['kind']
  self.attributes = value['attributes'].map { |val| val } unless value['attributes'].nil?
  self.visibility = value['visibility']
  self
end