Class: LSP::CallHierarchyClientCapabilities

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol_callhierarchy.proposed.rb

Overview

export interface CallHierarchyClientCapabilities { /** * The text document client capabilities / textDocument?: { /* * Capabilities specific to the textDocument/callHierarchy. * * @since 3.16.0 - Proposed state / callHierarchy?: { /* * Whether implementation supports dynamic registration. If this is set to true * the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions) * return value for the corresponding server capability as well. */ dynamicRegistration?: boolean; }; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ CallHierarchyClientCapabilities

/** * Capabilities specific to the textDocument/callHierarchy. * * @since 3.16.0 - Proposed state / callHierarchy?: { /* * Whether implementation supports dynamic registration. If this is set to true * the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions) * return value for the corresponding server capability as well. */ dynamicRegistration?: boolean; }; }



146
147
148
149
# File 'lib/lsp/lsp_protocol_callhierarchy.proposed.rb', line 146

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[textDocument]
end

Instance Attribute Details

#textDocumentObject

type: {



129
130
131
# File 'lib/lsp/lsp_protocol_callhierarchy.proposed.rb', line 129

def textDocument
  @textDocument
end

Instance Method Details

#from_h!(value) ⇒ Object



151
152
153
154
155
# File 'lib/lsp/lsp_protocol_callhierarchy.proposed.rb', line 151

def from_h!(value)
  value = {} if value.nil?
  self.textDocument = value['textDocument'] # Unknown type
  self
end