Class: LSP::DidChangeTextDocumentParams

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol.rb

Overview

export interface DidChangeTextDocumentParams { /** * The document that did change. The version number points * to the version after all provided content changes have * been applied. / textDocument: VersionedTextDocumentIdentifier; /* * The actual content changes. The content changes describe single state changes * to the document. So if there are two content changes c1 (at array index 0) and * c2 (at array index 1) for a document in state S then c1 moves the document from * S to S' and c2 from S' to S''. So c1 is computed on the state S and c2 is computed * on the state S'. * * To mirror the content of a document using change events use the following approach: * - start with the same initial content * - apply the 'textDocument/didChange' notifications in the order you recevie them. * - apply the TextDocumentContentChangeEvents in a single notification in the order * you receive them. */ contentChanges: TextDocumentContentChangeEvent; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#initialize, #to_h, #to_json

Constructor Details

This class inherits a constructor from LSP::LSPBase

Instance Attribute Details

#contentChangesObject

type: VersionedTextDocumentIdentifier # type: TextDocumentContentChangeEvent



580
581
582
# File 'lib/lsp/lsp_protocol.rb', line 580

def contentChanges
  @contentChanges
end

#textDocumentObject

type: VersionedTextDocumentIdentifier # type: TextDocumentContentChangeEvent



580
581
582
# File 'lib/lsp/lsp_protocol.rb', line 580

def textDocument
  @textDocument
end

Instance Method Details

#from_h!(value) ⇒ Object



582
583
584
585
586
587
# File 'lib/lsp/lsp_protocol.rb', line 582

def from_h!(value)
  value = {} if value.nil?
  self.textDocument = value['textDocument'] # Unknown type
  self.contentChanges = value['contentChanges'].map { |val| val } unless value['contentChanges'].nil? # Unknown array type
  self
end