Class: LSP::InitializeError

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol.rb

Overview

export interface InitializeError { /** * Indicates whether the client execute the following retry logic: * (1) show the message provided by the ResponseError to the user * (2) user selects retry or cancel * (3) if user selected retry the initialize method is sent again. */ retry: boolean; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#initialize, #to_h, #to_json

Constructor Details

This class inherits a constructor from LSP::LSPBase

Instance Attribute Details

#retryObject

type: boolean



294
295
296
# File 'lib/lsp/lsp_protocol.rb', line 294

def retry
  @retry
end

Instance Method Details

#from_h!(value) ⇒ Object



296
297
298
299
300
# File 'lib/lsp/lsp_protocol.rb', line 296

def from_h!(value)
  value = {} if value.nil?
  self.retry = value['retry'] # Unknown type
  self
end