Class: LSP::PublishDiagnosticsClientCapabilities

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol.rb

Overview

export interface PublishDiagnosticsClientCapabilities { /** * Whether the clients accepts diagnostics with related information. / relatedInformation?: boolean; /* * Client supports the tag property to provide meta data about a diagnostic. * Clients supporting tags have to handle unknown tags gracefully. * * @since 3.15.0 / tagSupport?: { /* * The tags supported by the client. / valueSet: DiagnosticTag; }; /* * Whether the client interprets the version property of the * textDocument/publishDiagnostics notification`s parameter. * * @since 3.15.0 */ versionSupport?: boolean; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ PublishDiagnosticsClientCapabilities

Returns a new instance of PublishDiagnosticsClientCapabilities.



833
834
835
836
# File 'lib/lsp/lsp_protocol.rb', line 833

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[relatedInformation tagSupport versionSupport]
end

Instance Attribute Details

#relatedInformationObject

type: boolean # type: {



825
826
827
# File 'lib/lsp/lsp_protocol.rb', line 825

def relatedInformation
  @relatedInformation
end

#tagSupportObject

type: boolean # type: {



825
826
827
# File 'lib/lsp/lsp_protocol.rb', line 825

def tagSupport
  @tagSupport
end

#versionSupportObject

/** * The tags supported by the client. */ valueSet: DiagnosticTag; }



831
832
833
# File 'lib/lsp/lsp_protocol.rb', line 831

def versionSupport
  @versionSupport
end

Instance Method Details

#from_h!(value) ⇒ Object



838
839
840
841
842
843
844
# File 'lib/lsp/lsp_protocol.rb', line 838

def from_h!(value)
  value = {} if value.nil?
  self.relatedInformation = value['relatedInformation'] # Unknown type
  self.tagSupport = value['tagSupport'] # Unknown type
  self.versionSupport = value['versionSupport'] # Unknown type
  self
end