Class: LSP::SignatureHelpClientCapabilities

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol.rb

Overview

export interface SignatureHelpClientCapabilities { /** * Whether signature help supports dynamic registration. / dynamicRegistration?: boolean; /* * The client supports the following SignatureInformation * specific properties. / signatureInformation?: { /* * Client supports the follow content formats for the documentation * property. The order describes the preferred format of the client. / documentationFormat?: MarkupKind; /* * Client capabilities specific to parameter information. / parameterInformation?: { /* * The client supports processing label offsets instead of a * simple label string. * * @since 3.14.0 / labelOffsetSupport?: boolean; }; }; /* * The client supports to send additional context information for a * textDocument/signatureHelp request. A client that opts into * contextSupport will also support the retriggerCharacters on * SignatureHelpOptions. * * @since 3.15.0 */ contextSupport?: boolean; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ SignatureHelpClientCapabilities

Returns a new instance of SignatureHelpClientCapabilities.



1285
1286
1287
1288
# File 'lib/lsp/lsp_protocol.rb', line 1285

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[dynamicRegistration signatureInformation contextSupport]
end

Instance Attribute Details

#contextSupportObject

/** * Client supports the follow content formats for the documentation * property. The order describes the preferred format of the client. / documentationFormat?: MarkupKind; /* * Client capabilities specific to parameter information. / parameterInformation?: { /* * The client supports processing label offsets instead of a * simple label string. * * @since 3.14.0 */ labelOffsetSupport?: boolean; }; }



1283
1284
1285
# File 'lib/lsp/lsp_protocol.rb', line 1283

def contextSupport
  @contextSupport
end

#dynamicRegistrationObject

type: boolean # type: {



1264
1265
1266
# File 'lib/lsp/lsp_protocol.rb', line 1264

def dynamicRegistration
  @dynamicRegistration
end

#signatureInformationObject

type: boolean # type: {



1264
1265
1266
# File 'lib/lsp/lsp_protocol.rb', line 1264

def signatureInformation
  @signatureInformation
end

Instance Method Details

#from_h!(value) ⇒ Object



1290
1291
1292
1293
1294
1295
1296
# File 'lib/lsp/lsp_protocol.rb', line 1290

def from_h!(value)
  value = {} if value.nil?
  self.dynamicRegistration = value['dynamicRegistration'] # Unknown type
  self.signatureInformation = value['signatureInformation'] # Unknown type
  self.contextSupport = value['contextSupport'] # Unknown type
  self
end