Class: LSP::WorkspaceFoldersServerCapabilities

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol_workspacefolders.rb

Overview

export interface WorkspaceFoldersServerCapabilities { /** * The workspace server capabilities / workspace?: { workspaceFolders?: { /* * The Server has support for workspace folders / supported?: boolean; /* * Whether the server wants to receive workspace folder * change notifications. * * If a strings is provided the string is treated as a ID * under which the notification is registed on the client * side. The ID can be used to unregister for these events * using the client/unregisterCapability request. */ changeNotifications?: string | boolean; }; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ WorkspaceFoldersServerCapabilities

workspaceFolders?: { /** * The Server has support for workspace folders / supported?: boolean; /* * Whether the server wants to receive workspace folder * change notifications. * * If a strings is provided the string is treated as a ID * under which the notification is registed on the client * side. The ID can be used to unregister for these events * using the client/unregisterCapability request. */ changeNotifications?: string | boolean; }; }



101
102
103
104
# File 'lib/lsp/lsp_protocol_workspacefolders.rb', line 101

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[workspace]
end

Instance Attribute Details

#workspaceObject

type: {



81
82
83
# File 'lib/lsp/lsp_protocol_workspacefolders.rb', line 81

def workspace
  @workspace
end

Instance Method Details

#from_h!(value) ⇒ Object



106
107
108
109
110
# File 'lib/lsp/lsp_protocol_workspacefolders.rb', line 106

def from_h!(value)
  value = {} if value.nil?
  self.workspace = value['workspace'] # Unknown type
  self
end