Class: LSP::WorkspaceSymbolClientCapabilities

Inherits:
LSPBase
  • Object
show all
Defined in:
lib/lsp/lsp_protocol.rb

Overview

export interface WorkspaceSymbolClientCapabilities { /** * Symbol request supports dynamic registration. / dynamicRegistration?: boolean; /* * Specific capabilities for the SymbolKind in the workspace/symbol request. / symbolKind?: { /* * The symbol kind values the client supports. When this * property exists the client also guarantees that it will * handle values outside its set gracefully and falls back * to a default value when unknown. * * If this property is not present the client only supports * the symbol kinds from File to Array as defined in * the initial version of the protocol. */ valueSet?: SymbolKind; }; }

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from LSPBase

#to_h, #to_json

Constructor Details

#initialize(initial_hash = nil) ⇒ WorkspaceSymbolClientCapabilities

/** * The symbol kind values the client supports. When this * property exists the client also guarantees that it will * handle values outside its set gracefully and falls back * to a default value when unknown. * * If this property is not present the client only supports * the symbol kinds from File to Array as defined in * the initial version of the protocol. */ valueSet?: SymbolKind; }



1952
1953
1954
1955
# File 'lib/lsp/lsp_protocol.rb', line 1952

def initialize(initial_hash = nil)
  super
  @optional_method_names = %i[dynamicRegistration symbolKind]
end

Instance Attribute Details

#dynamicRegistrationObject

type: boolean # type: {



1937
1938
1939
# File 'lib/lsp/lsp_protocol.rb', line 1937

def dynamicRegistration
  @dynamicRegistration
end

#symbolKindObject

type: boolean # type: {



1937
1938
1939
# File 'lib/lsp/lsp_protocol.rb', line 1937

def symbolKind
  @symbolKind
end

Instance Method Details

#from_h!(value) ⇒ Object



1957
1958
1959
1960
1961
1962
# File 'lib/lsp/lsp_protocol.rb', line 1957

def from_h!(value)
  value = {} if value.nil?
  self.dynamicRegistration = value['dynamicRegistration'] # Unknown type
  self.symbolKind = value['symbolKind'] # Unknown type
  self
end