Class: DSP::Breakpoint
Overview
interface Breakpoint { /** An optional identifier for the breakpoint. It is needed if breakpoint events are used to update or remove breakpoints. / id?: number; /* If true breakpoint could be set (but not necessarily at the desired location). / verified: boolean; /* An optional message about the state of the breakpoint. This is shown to the user and can be used to explain why a breakpoint could not be verified. / message?: string; /* The source where the breakpoint is located. / source?: Source; /* The start line of the actual range covered by the breakpoint. / line?: number; /* An optional start column of the actual range covered by the breakpoint. / column?: number; /* An optional end line of the actual range covered by the breakpoint. / endLine?: number; /* An optional end column of the actual range covered by the breakpoint. If no end line is given, then the end column is assumed to be in the start line. */ endColumn?: number; }
Instance Attribute Summary collapse
-
#column ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#endColumn ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#endLine ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#id ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#line ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#message ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#source ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
-
#verified ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number.
Instance Method Summary collapse
- #from_h!(value) ⇒ Object
-
#initialize(initial_hash = nil) ⇒ Breakpoint
constructor
A new instance of Breakpoint.
Methods inherited from DSPBase
Constructor Details
#initialize(initial_hash = nil) ⇒ Breakpoint
Returns a new instance of Breakpoint.
4291 4292 4293 4294 |
# File 'lib/dsp/dsp_protocol.rb', line 4291 def initialize(initial_hash = nil) super @optional_method_names = %i[id message source line column endLine endColumn] end |
Instance Attribute Details
#column ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def column @column end |
#endColumn ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def endColumn @endColumn end |
#endLine ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def endLine @endLine end |
#id ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def id @id end |
#line ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def line @line end |
#message ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def @message end |
#source ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def source @source end |
#verified ⇒ Object
type: number # type: boolean # type: string # type: Source # type: number # type: number # type: number # type: number
4289 4290 4291 |
# File 'lib/dsp/dsp_protocol.rb', line 4289 def verified @verified end |
Instance Method Details
#from_h!(value) ⇒ Object
4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 |
# File 'lib/dsp/dsp_protocol.rb', line 4296 def from_h!(value) value = {} if value.nil? self.id = value['id'] self.verified = value['verified'] # Unknown type self. = value['message'] self.source = Source.new(value['source']) unless value['source'].nil? self.line = value['line'] self.column = value['column'] self.endLine = value['endLine'] self.endColumn = value['endColumn'] self end |