Class: DSP::CompletionsArguments
- Defined in:
- lib/dsp/dsp_protocol.rb
Overview
interface CompletionsArguments { /** Returns completions in the scope of this stack frame. If not specified, the completions are returned for the global scope. / frameId?: number; /* One or more source lines. Typically this is the text a user has typed into the debug console before he asked for completion. / text: string; /* The character position for which to determine the completion proposals. / column: number; /* An optional line for which to determine the completion proposals. If missing the first line of the text is assumed. */ line?: number; }
Instance Attribute Summary collapse
-
#column ⇒ Object
type: number # type: string # type: number # type: number.
-
#frameId ⇒ Object
type: number # type: string # type: number # type: number.
-
#line ⇒ Object
type: number # type: string # type: number # type: number.
-
#text ⇒ Object
type: number # type: string # type: number # type: number.
Instance Method Summary collapse
- #from_h!(value) ⇒ Object
-
#initialize(initial_hash = nil) ⇒ CompletionsArguments
constructor
A new instance of CompletionsArguments.
Methods inherited from DSPBase
Constructor Details
#initialize(initial_hash = nil) ⇒ CompletionsArguments
Returns a new instance of CompletionsArguments.
3294 3295 3296 3297 |
# File 'lib/dsp/dsp_protocol.rb', line 3294 def initialize(initial_hash = nil) super @optional_method_names = %i[frameId line] end |
Instance Attribute Details
#column ⇒ Object
type: number # type: string # type: number # type: number
3292 3293 3294 |
# File 'lib/dsp/dsp_protocol.rb', line 3292 def column @column end |
#frameId ⇒ Object
type: number # type: string # type: number # type: number
3292 3293 3294 |
# File 'lib/dsp/dsp_protocol.rb', line 3292 def frameId @frameId end |
#line ⇒ Object
type: number # type: string # type: number # type: number
3292 3293 3294 |
# File 'lib/dsp/dsp_protocol.rb', line 3292 def line @line end |
#text ⇒ Object
type: number # type: string # type: number # type: number
3292 3293 3294 |
# File 'lib/dsp/dsp_protocol.rb', line 3292 def text @text end |
Instance Method Details
#from_h!(value) ⇒ Object
3299 3300 3301 3302 3303 3304 3305 3306 |
# File 'lib/dsp/dsp_protocol.rb', line 3299 def from_h!(value) value = {} if value.nil? self.frameId = value['frameId'] self.text = value['text'] self.column = value['column'] self.line = value['line'] self end |