Class: DSP::ProcessEvent
Overview
interface ProcessEvent extends Event { body: { /** The logical name of the process. This is usually the full path to process's executable file. Example: /home/example/myproj/program.js. / name: string; /* The system process id of the debugged process. This property will be missing for non-system processes. / systemProcessId?: number; /* If true, the process is running on the same computer as the debug adapter. / isLocalProcess?: boolean; /* Describes how the debug engine started debugging this process. 'launch': Process was launched under the debugger. 'attach': Debugger attached to an existing process. 'attachForSuspendedLaunch': A project launcher component has launched a new process in a suspended state and then asked the debugger to attach. / startMethod?: 'launch' | 'attach' | 'attachForSuspendedLaunch'; /* The size of a pointer or address for this process, in bits. This value may be used by clients when formatting addresses for display. */ pointerSize?: number; }; }
Instance Attribute Summary collapse
-
#body ⇒ Object
type: {.
-
#event ⇒ Object
/** The logical name of the process.
-
#seq ⇒ Object
type: {.
-
#type ⇒ Object
type: {.
Instance Method Summary collapse
Methods inherited from DSPBase
Constructor Details
This class inherits a constructor from DSP::DSPBase
Instance Attribute Details
#body ⇒ Object
type: {
583 584 585 |
# File 'lib/dsp/dsp_protocol.rb', line 583 def body @body end |
#event ⇒ Object
/** The logical name of the process. This is usually the full path to process's executable file. Example: /home/example/myproj/program.js. / name: string; /* The system process id of the debugged process. This property will be missing for non-system processes. / systemProcessId?: number; /* If true, the process is running on the same computer as the debug adapter. / isLocalProcess?: boolean; /* Describes how the debug engine started debugging this process. 'launch': Process was launched under the debugger. 'attach': Debugger attached to an existing process. 'attachForSuspendedLaunch': A project launcher component has launched a new process in a suspended state and then asked the debugger to attach. / startMethod?: 'launch' | 'attach' | 'attachForSuspendedLaunch'; /* The size of a pointer or address for this process, in bits. This value may be used by clients when formatting addresses for display. */ pointerSize?: number; }
599 600 601 |
# File 'lib/dsp/dsp_protocol.rb', line 599 def event @event end |
#seq ⇒ Object
type: {
583 584 585 |
# File 'lib/dsp/dsp_protocol.rb', line 583 def seq @seq end |
#type ⇒ Object
type: {
583 584 585 |
# File 'lib/dsp/dsp_protocol.rb', line 583 def type @type end |
Instance Method Details
#from_h!(value) ⇒ Object
601 602 603 604 605 606 607 608 |
# File 'lib/dsp/dsp_protocol.rb', line 601 def from_h!(value) value = {} if value.nil? self.body = value['body'] # Unknown type self.event = value['event'] self.seq = value['seq'] self.type = value['type'] self end |