Class: LSP::InitializeResult
Overview
export interface InitializeResult<T = any> {
/**
* The capabilities the language server provides.
/
capabilities: ServerCapabilities
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
type: ServerCapabilities
# type: {. -
#serverInfo ⇒ Object
type: ServerCapabilities
# type: {.
Instance Method Summary collapse
- #from_h!(value) ⇒ Object
-
#initialize(initial_hash = nil) ⇒ InitializeResult
constructor
/** * The name of the server as defined by the server.
Methods inherited from LSPBase
Constructor Details
#initialize(initial_hash = nil) ⇒ InitializeResult
/** * The name of the server as defined by the server. / name: string; /* * The servers's version as defined by the server. */ version?: string; }
271 272 273 274 |
# File 'lib/lsp/lsp_protocol.rb', line 271 def initialize(initial_hash = nil) super @optional_method_names = %i[serverInfo] end |
Instance Attribute Details
#capabilities ⇒ Object
type: ServerCapabilities
259 260 261 |
# File 'lib/lsp/lsp_protocol.rb', line 259 def capabilities @capabilities end |
#serverInfo ⇒ Object
type: ServerCapabilities
259 260 261 |
# File 'lib/lsp/lsp_protocol.rb', line 259 def serverInfo @serverInfo end |
Instance Method Details
#from_h!(value) ⇒ Object
276 277 278 279 280 281 |
# File 'lib/lsp/lsp_protocol.rb', line 276 def from_h!(value) value = {} if value.nil? self.capabilities = value['capabilities'] # Unknown type self.serverInfo = value['serverInfo'] # Unknown type self end |