Class: LSP::SemanticTokensClientCapabilities
- Defined in:
- lib/lsp/lsp_protocol_sematictokens.proposed.rb
Overview
export interface SemanticTokensClientCapabilities {
/**
* The text document client capabilities
/
textDocument?: {
/*
* Capabilities specific to the textDocument/semanticTokens
*
* @since 3.16.0 - Proposed state
/
semanticTokens?: {
/*
* Whether implementation supports dynamic registration. If this is set to true
* the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions)
* return value for the corresponding server capability as well.
/
dynamicRegistration?: boolean;
/*
* The token types know by the client.
/
tokenTypes: string;
/*
* The token modifiers know by the client.
*/
tokenModifiers: string;
};
};
}
Instance Attribute Summary collapse
-
#textDocument ⇒ Object
type: {.
Instance Method Summary collapse
- #from_h!(value) ⇒ Object
-
#initialize(initial_hash = nil) ⇒ SemanticTokensClientCapabilities
constructor
/** * Capabilities specific to the
textDocument/semanticTokens* * @since 3.16.0 - Proposed state / semanticTokens?: { /* * Whether implementation supports dynamic registration. If this is set totrue* the client supports the new(TextDocumentRegistrationOptions & StaticRegistrationOptions)* return value for the corresponding server capability as well. / dynamicRegistration?: boolean; /* * The token types know by the client. / tokenTypes: string; /* * The token modifiers know by the client. */ tokenModifiers: string; }; }.
Methods inherited from LSPBase
Constructor Details
#initialize(initial_hash = nil) ⇒ SemanticTokensClientCapabilities
/**
* Capabilities specific to the textDocument/semanticTokens
*
* @since 3.16.0 - Proposed state
/
semanticTokens?: {
/*
* Whether implementation supports dynamic registration. If this is set to true
* the client supports the new (TextDocumentRegistrationOptions & StaticRegistrationOptions)
* return value for the corresponding server capability as well.
/
dynamicRegistration?: boolean;
/*
* The token types know by the client.
/
tokenTypes: string;
/*
* The token modifiers know by the client.
*/
tokenModifiers: string;
};
}
187 188 189 190 |
# File 'lib/lsp/lsp_protocol_sematictokens.proposed.rb', line 187 def initialize(initial_hash = nil) super @optional_method_names = %i[textDocument] end |
Instance Attribute Details
#textDocument ⇒ Object
type: {
162 163 164 |
# File 'lib/lsp/lsp_protocol_sematictokens.proposed.rb', line 162 def textDocument @textDocument end |
Instance Method Details
#from_h!(value) ⇒ Object
192 193 194 195 196 |
# File 'lib/lsp/lsp_protocol_sematictokens.proposed.rb', line 192 def from_h!(value) value = {} if value.nil? self.textDocument = value['textDocument'] # Unknown type self end |