Class: LSP::TextEdit
Overview
export interface TextEdit { /** * The range of the text document to be manipulated. To insert * text into a document create a range where start === end. / range: Range; /* * The string to be inserted. For delete operations use an * empty string. */ newText: string; }
Instance Attribute Summary collapse
-
#newText ⇒ Object
type: Range # type: string.
-
#range ⇒ Object
type: Range # type: string.
Instance Method Summary collapse
Methods inherited from LSPBase
Constructor Details
This class inherits a constructor from LSP::LSPBase
Instance Attribute Details
#newText ⇒ Object
type: Range # type: string
370 371 372 |
# File 'lib/lsp/lsp_types.rb', line 370 def newText @newText end |
#range ⇒ Object
type: Range # type: string
370 371 372 |
# File 'lib/lsp/lsp_types.rb', line 370 def range @range end |